==> drools-quarkus-unit-example-0.6.0-sources.jar: org/kie/kogito/rules/alerting/Rules4723952D402A230BDB0E7081EBBA10E2_MonitoringServiceRuleMethods0.java <==
package org.kie.kogito.rules.alerting;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import static org.kie.kogito.rules.alerting.Rules4723952D402A230BDB0E7081EBBA10E2.*;

public class Rules4723952D402A230BDB0E7081EBBA10E2_MonitoringServiceRuleMethods0 {

    /**
     * Rule name: org.kie.kogito.rules.alerting.MonitoringService.IncomingEvent
     */
    public static org.drools.model.Rule rule_org_46kie_46kogito_46rules_46alerting_46MonitoringService_46IncomingEvent() {
        final org.drools.model.Variable<org.kie.kogito.rules.alerting.Event> var_$e = D.declarationOf(org.kie.kogito.rules.alerting.Event.class,
                                                                                                      DomainClassesMetadata4723952D402A230BDB0E7081EBBA10E2.org_kie_kogito_rules_alerting_Event_Metadata_INSTANCE,
                                                                                                      "$e",
                                                                                                      D.entryPoint("eventStream"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.rules.alerting",
                                            "org.kie.kogito.rules.alerting.MonitoringService.IncomingEvent").unit(org.kie.kogito.rules.alerting.MonitoringService.class)
                                                                                                            .build(D.pattern(var_$e),
                                                                                                                   D.on(var_$e,
                                                                                                                        var_alertStream).execute(($e, alertStream) -> {
                                                                                                                       System.out.println("incoming event: " + $e.getMessage());
                                                                                                                       alertStream.append(new Alert("I have received a message: " + $e));
                                                                                                                   }));
        return rule;
    }
}

==> drools-quarkus-unit-example-0.7.1-sources.jar: org/kie/kogito/rules/alerting/Rules4723952D402A230BDB0E7081EBBA10E2_MonitoringServiceRuleMethods0.java <==
package org.kie.kogito.rules.alerting;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import static org.kie.kogito.rules.alerting.Rules4723952D402A230BDB0E7081EBBA10E2.*;

public class Rules4723952D402A230BDB0E7081EBBA10E2_MonitoringServiceRuleMethods0 {

    /**
     * Rule name: org.kie.kogito.rules.alerting.MonitoringService.IncomingEvent
     */
    public static org.drools.model.Rule rule_org_46kie_46kogito_46rules_46alerting_46MonitoringService_46IncomingEvent() {
        final org.drools.model.Variable<org.kie.kogito.rules.alerting.Event> var_$e = D.declarationOf(org.kie.kogito.rules.alerting.Event.class,
                                                                                                      DomainClassesMetadata4723952D402A230BDB0E7081EBBA10E2.org_kie_kogito_rules_alerting_Event_Metadata_INSTANCE,
                                                                                                      "$e",
                                                                                                      D.entryPoint("eventStream"));
        org.drools.model.Rule rule = D.rule("org.kie.kogito.rules.alerting",
                                            "org.kie.kogito.rules.alerting.MonitoringService.IncomingEvent").unit(org.kie.kogito.rules.alerting.MonitoringService.class)
                                                                                                            .build(D.pattern(var_$e),
                                                                                                                   D.on(var_$e,
                                                                                                                        var_alertStream).execute((org.kie.kogito.rules.alerting.Event $e, org.kie.kogito.rules.DataStream alertStream) -> {
                                                                                                                       System.out.println("incoming event: " + $e.getMessage());
                                                                                                                       alertStream.append(new Alert("I have received a message: " + $e));
                                                                                                                   }));
        return rule;
    }
}
